﻿using CallCenter.BlackLists;
using CallCenter.Calls;
using Google.Protobuf.WellKnownTypes;
using XF.Domain.Cache;
using XF.Domain.Dependency;

namespace CallCenter.Caches
{
    public class CallCacheManager : ICallCacheManager, IScopeDependency
    {
        private readonly ITypedCache<CallDtoRedis> _cacheCall;

        public class CallDtoRedis
        {
            public string FromNo { get; set; }
            public string ToNo { get; set; }
            public DateTime InGroupTime { get; set; }

            public string TrunkNo { get; set; }

            public string GroupNo { get; set; }
        }

        public CallCacheManager(ITypedCache<CallDtoRedis> cacheCall)
        {
            _cacheCall = cacheCall;
        }

        public void AddCallCache(Call call,string groupNo)
        {
            _cacheCall.Set(call.Id,  new CallDtoRedis{ FromNo =call.FromNo,ToNo = call.ToNo, InGroupTime = DateTime.Now, TrunkNo=call.Trunk, GroupNo = groupNo }, TimeSpan.FromSeconds(90));
        }

        public List<CallDtoRedis> GetCallQueueList()
        {
            var list = _cacheCall.GetListByPrefix().ToList();
            return list==null ? new List<CallDtoRedis>() : list;
        }

        public int GetCallQueueList(string groupNo)
        {
            return _cacheCall.GetListByPrefix().Where(x => x.GroupNo == groupNo).Count();
        }



        public void RemoveCallCache(string id)
        {
            _cacheCall.Remove(id);
        }
    }
}
